@@ -20,6 +20,7 @@ import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 
+import java.util.Locale;
 import org.apache.commons.lang.StringEscapeUtils;
 
 import com.clustercontrol.jobmanagement.bean.ForwardFileTableDefine;
@@ -30,6 +31,7 @@ import com.clustercontrol.jobmanagement.bean.JobNodeDetail;
 import com.clustercontrol.jobmanagement.bean.JobSchedule;
 import com.clustercontrol.jobmanagement.bean.NodeDetailTableDefine;
 import com.clustercontrol.jobmanagement.bean.ScheduleTableDefine;
+import com.necsoft.hinemos.webclient.bean.JobTriggerTypeConstant;
 
 /**
  * 表示用のリストに変換するクラス
@@ -154,7 +156,7 @@ public class ConvertListUtil {
      * History
      */
     public static List<List<Object>> jobHistoryListToArrayList(
-            List<JobHistory> list) {
+            List<JobHistory> list, Locale locale) {
 
         List<List<Object>> ret = new ArrayList<List<Object>>();
         Iterator<JobHistory> itr = list.iterator();
@@ -202,8 +204,9 @@ public class ConvertListUtil {
                     scheduleStartDate);
             history.add(HistoryTableDefine.START_RERUN_TIME, startDate);
             history.add(HistoryTableDefine.END_SUSPEND_TIME, endDate);
-            history.add(HistoryTableDefine.TRIGGER_TYPE,
-                    jobHist.getJobTriggerType());
+            history.add(HistoryTableDefine.TRIGGER_TYPE, 
+                    JobTriggerTypeConstant.typeToString(
+                            JobTriggerTypeConstant.stringToType(jobHist.getJobTriggerType()), locale));
             history.add(HistoryTableDefine.TRIGGER_INFO,
                     jobHist.getTriggerInfo());
 
